#!/usr/bin/python3

import sys

if __name__ == "__main__":
    print("Key 0")
    print("Key 1")
    print("Key 2")
    sys.stdout.flush()
